@@ -19,12 +19,13 @@ use vars qw(@EXPORT @ISA $VERSION $AUTOLOAD);
 	     megahal_initial_greeting
 	     megahal_command
 	     megahal_do_reply
+	     megahal_learn
 	     megahal_output
 	     megahal_input
 	     megahal_cleanup);
 
 @ISA = qw(Exporter DynaLoader);
-$VERSION = '0.06';
+$VERSION = '0.07';
 
 sub AUTOLOAD {
     # This AUTOLOAD is used to 'autoload' constants from the constant()
@@ -88,19 +89,25 @@ sub new {
     return $self;
 }
 
-sub initial_greeting() {
+sub initial_greeting {
     my $self = shift;
 
     return megahal_initial_greeting();
 }
 
-sub do_reply() {
+sub do_reply {
     my ($self,$text) = @_;
 
     return megahal_do_reply($text,0);
 }
 
-sub _initialize() {
+sub learn {
+    my ($self,$text) = @_;
+
+    return megahal_learn($text,0);
+}
+
+sub _initialize {
     my $self = shift;
 
     megahal_initialize();
@@ -134,16 +141,18 @@ AI::MegaHAL - Perl interface to the MegaHAL natural language conversation simula
 
 use AI::MegaHAL;
 
-$megahal = AI::new MegaHAL('Path'     => './',
+my $megahal = AI::MegaHAL->new('Path'     => './',
                            'Banner'   => 0,
                            'Prompt'   => 0,
                            'Wrap'     => 0,
                            'AutoSave' => 0);
 
-$text = $megahal->initial_greeting();
+my $text = $megahal->initial_greeting();
 
 $text = $megahal->do_reply($message);
 
+$megahal->learn($message);
+
 =head1 DESCRIPTION
 
 Conversation simulators are computer programs which give the appearance of conversing with a user in natural language.  Such programs are effective because they exploit the fact that human beings tend to read much more meaning into what is said than is actually there; we are fooled into reading structure into chaos, and we  interpret non-sequitur as valid conversation.
@@ -152,7 +161,7 @@ This package provides a Perl interface to the MegaHAL conversation simulator wri
 
 =head1 CONSTRUCTOR
 
-$megahal = new AI::MegaHAL('Path'     => './',
+$megahal = AI::MegaHAL->new('Path'     => './',
                            'Banner'   => 0,
                            'Prompt'   => 0,
                            'Wrap'     => 0,
@@ -186,10 +195,21 @@ $text = $megahal->do_reply($message);
 
 Generates reply $text to a given message $message.
 
+=head2 learn
+
+$megahal->learn($message);
+
+Learns from $message without generating a response
+
 =head1 BUGS
 
 None known at this time.
 
+=head1 SEE ALSO
+
+POE::Component::AI::MegaHAL - IRC bot,
+L<http://teaandbiscuits.org.uk/drupal/node/65> - Irssi IRC bot
+
 =head1 AUTHOR
 
 The Perl AI::MegaHAL interface was written by Cory Spencer <cspencer[at]sprocket.org>.
